.. _sec-advanced:

Advanced: DisCoPy usage
=======================

To understand ``lambeq`` in further depth, it is necessary to familiarise yourself with :ref:`sec-discopy`, the underlying library used for manipulating :term:`monoidal categories <monoidal category>`. After these tutorials, you will have the necessary knowledge to contribute to ``lambeq`` and DisCoPy.

.. toctree::

    ../tutorials/monoidal.ipynb
    ../tutorials/discocat.ipynb
